{-# OPTIONS_GHC -Wall #-}
{-# OPTIONS_GHC -fno-warn-unused-imports #-}
{-# OPTIONS_GHC -fno-warn-orphans #-}
{-# Language ForeignFunctionInterface #-}
{-# Language FlexibleInstances #-}
{-# Language MultiParamTypeClasses #-}

module Casadi.Core.Classes.HomotopyNLPSolver
       (
         HomotopyNLPSolver,
         HomotopyNLPSolverClass(..),
         homotopyNLPSolver,
         homotopyNLPSolver_doc,
         homotopyNLPSolver_loadPlugin,
       ) where


import Prelude hiding ( Functor )

import Data.Vector ( Vector )
import Foreign.C.Types
import Foreign.Marshal ( new, free )
import Foreign.Storable ( peek )
import Foreign.Ptr ( Ptr, nullPtr )
import Foreign.ForeignPtr ( newForeignPtr )
import System.IO.Unsafe ( unsafePerformIO ) -- for show instances

import Casadi.Core.Classes.PrintableObject
import Casadi.Internal.CToolsInstances ( )
import Casadi.Internal.FormatException ( formatException )
import Casadi.Internal.MarshalTypes ( StdVec, StdString) -- StdPair StdOstream'
import Casadi.Internal.Marshal ( Marshal(..), withMarshal )
import Casadi.Internal.WrapReturn ( WrapReturn(..) )
import Casadi.Core.Data
import Casadi.Core.Enums

instance Show HomotopyNLPSolver where
  show = unsafePerformIO . printableObject_getDescription
-- direct wrapper
foreign import ccall unsafe "casadi__HomotopyNLPSolver__CONSTRUCTOR" c_casadi__HomotopyNLPSolver__CONSTRUCTOR
  :: Ptr (Ptr StdString) -> IO (Ptr HomotopyNLPSolver')
casadi__HomotopyNLPSolver__CONSTRUCTOR
  :: IO HomotopyNLPSolver
casadi__HomotopyNLPSolver__CONSTRUCTOR  =

  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__HomotopyNLPSolver__CONSTRUCTOR errStrPtrP 
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
homotopyNLPSolver :: IO HomotopyNLPSolver
homotopyNLPSolver = casadi__HomotopyNLPSolver__CONSTRUCTOR


-- direct wrapper
foreign import ccall unsafe "casadi__HomotopyNLPSolver__doc" c_casadi__HomotopyNLPSolver__doc
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO (Ptr StdString)
casadi__HomotopyNLPSolver__doc
  :: String -> IO String
casadi__HomotopyNLPSolver__doc x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__HomotopyNLPSolver__doc errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
homotopyNLPSolver_doc :: String -> IO String
homotopyNLPSolver_doc = casadi__HomotopyNLPSolver__doc


-- direct wrapper
foreign import ccall unsafe "casadi__HomotopyNLPSolver__loadPlugin" c_casadi__HomotopyNLPSolver__loadPlugin
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO ()
casadi__HomotopyNLPSolver__loadPlugin
  :: String -> IO ()
casadi__HomotopyNLPSolver__loadPlugin x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__HomotopyNLPSolver__loadPlugin errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
homotopyNLPSolver_loadPlugin :: String -> IO ()
homotopyNLPSolver_loadPlugin = casadi__HomotopyNLPSolver__loadPlugin

