{-# OPTIONS_GHC -Wall #-}
{-# OPTIONS_GHC -fno-warn-unused-imports #-}
{-# OPTIONS_GHC -fno-warn-orphans #-}
{-# Language ForeignFunctionInterface #-}
{-# Language FlexibleInstances #-}
{-# Language MultiParamTypeClasses #-}

module Casadi.Core.Classes.QPSolver
       (
         QPSolver,
         QPSolverClass(..),
         qpSolver,
         qpSolver_doc,
         qpSolver_generateNativeCode,
         qpSolver_loadPlugin,
         qpSolver_setLPOptions,
       ) where


import Prelude hiding ( Functor )

import Data.Vector ( Vector )
import Foreign.C.Types
import Foreign.Marshal ( new, free )
import Foreign.Storable ( peek )
import Foreign.Ptr ( Ptr, nullPtr )
import Foreign.ForeignPtr ( newForeignPtr )
import System.IO.Unsafe ( unsafePerformIO ) -- for show instances

import Casadi.Core.Classes.PrintableObject
import Casadi.Internal.CToolsInstances ( )
import Casadi.Internal.FormatException ( formatException )
import Casadi.Internal.MarshalTypes ( StdVec, StdString) -- StdPair StdOstream'
import Casadi.Internal.Marshal ( Marshal(..), withMarshal )
import Casadi.Internal.WrapReturn ( WrapReturn(..) )
import Casadi.Core.Data
import Casadi.Core.Enums

instance Show QPSolver where
  show = unsafePerformIO . printableObject_getDescription
-- direct wrapper
foreign import ccall unsafe "casadi__QPSolver__CONSTRUCTOR" c_casadi__QPSolver__CONSTRUCTOR
  :: Ptr (Ptr StdString) -> IO (Ptr QPSolver')
casadi__QPSolver__CONSTRUCTOR
  :: IO QPSolver
casadi__QPSolver__CONSTRUCTOR  =

  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__QPSolver__CONSTRUCTOR errStrPtrP 
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
qpSolver :: IO QPSolver
qpSolver = casadi__QPSolver__CONSTRUCTOR


-- direct wrapper
foreign import ccall unsafe "casadi__QPSolver__doc" c_casadi__QPSolver__doc
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO (Ptr StdString)
casadi__QPSolver__doc
  :: String -> IO String
casadi__QPSolver__doc x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__QPSolver__doc errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
qpSolver_doc :: String -> IO String
qpSolver_doc = casadi__QPSolver__doc


-- direct wrapper
foreign import ccall unsafe "casadi__QPSolver__generateNativeCode" c_casadi__QPSolver__generateNativeCode
  :: Ptr (Ptr StdString) -> Ptr QPSolver' -> Ptr StdString -> IO ()
casadi__QPSolver__generateNativeCode
  :: QPSolver -> String -> IO ()
casadi__QPSolver__generateNativeCode x0 x1 =
  withMarshal x0 $ \x0' ->
  withMarshal x1 $ \x1' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__QPSolver__generateNativeCode errStrPtrP x0' x1'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
qpSolver_generateNativeCode :: QPSolverClass a => a -> String -> IO ()
qpSolver_generateNativeCode x = casadi__QPSolver__generateNativeCode (castQPSolver x)


-- direct wrapper
foreign import ccall unsafe "casadi__QPSolver__loadPlugin" c_casadi__QPSolver__loadPlugin
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO ()
casadi__QPSolver__loadPlugin
  :: String -> IO ()
casadi__QPSolver__loadPlugin x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__QPSolver__loadPlugin errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
qpSolver_loadPlugin :: String -> IO ()
qpSolver_loadPlugin = casadi__QPSolver__loadPlugin


-- direct wrapper
foreign import ccall unsafe "casadi__QPSolver__setLPOptions" c_casadi__QPSolver__setLPOptions
  :: Ptr (Ptr StdString) -> Ptr QPSolver' -> IO ()
casadi__QPSolver__setLPOptions
  :: QPSolver -> IO ()
casadi__QPSolver__setLPOptions x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__QPSolver__setLPOptions errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
qpSolver_setLPOptions :: QPSolverClass a => a -> IO ()
qpSolver_setLPOptions x = casadi__QPSolver__setLPOptions (castQPSolver x)

