{-# OPTIONS_GHC -Wall #-}
{-# OPTIONS_GHC -fno-warn-unused-imports #-}
{-# OPTIONS_GHC -fno-warn-orphans #-}
{-# Language ForeignFunctionInterface #-}
{-# Language FlexibleInstances #-}
{-# Language MultiParamTypeClasses #-}

module Casadi.Core.Classes.SDPSolver
       (
         SDPSolver,
         SDPSolverClass(..),
         sdpSolver,
         sdpSolver_doc,
         sdpSolver_loadPlugin,
         sdpSolver_setSOCPOptions,
       ) where


import Prelude hiding ( Functor )

import Data.Vector ( Vector )
import Foreign.C.Types
import Foreign.Marshal ( new, free )
import Foreign.Storable ( peek )
import Foreign.Ptr ( Ptr, nullPtr )
import Foreign.ForeignPtr ( newForeignPtr )
import System.IO.Unsafe ( unsafePerformIO ) -- for show instances

import Casadi.Core.Classes.PrintableObject
import Casadi.Internal.CToolsInstances ( )
import Casadi.Internal.FormatException ( formatException )
import Casadi.Internal.MarshalTypes ( StdVec, StdString) -- StdPair StdOstream'
import Casadi.Internal.Marshal ( Marshal(..), withMarshal )
import Casadi.Internal.WrapReturn ( WrapReturn(..) )
import Casadi.Core.Data
import Casadi.Core.Enums

instance Show SDPSolver where
  show = unsafePerformIO . printableObject_getDescription
-- direct wrapper
foreign import ccall unsafe "casadi__SDPSolver__CONSTRUCTOR" c_casadi__SDPSolver__CONSTRUCTOR
  :: Ptr (Ptr StdString) -> IO (Ptr SDPSolver')
casadi__SDPSolver__CONSTRUCTOR
  :: IO SDPSolver
casadi__SDPSolver__CONSTRUCTOR  =

  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__SDPSolver__CONSTRUCTOR errStrPtrP 
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
sdpSolver :: IO SDPSolver
sdpSolver = casadi__SDPSolver__CONSTRUCTOR


-- direct wrapper
foreign import ccall unsafe "casadi__SDPSolver__doc" c_casadi__SDPSolver__doc
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO (Ptr StdString)
casadi__SDPSolver__doc
  :: String -> IO String
casadi__SDPSolver__doc x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__SDPSolver__doc errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
sdpSolver_doc :: String -> IO String
sdpSolver_doc = casadi__SDPSolver__doc


-- direct wrapper
foreign import ccall unsafe "casadi__SDPSolver__loadPlugin" c_casadi__SDPSolver__loadPlugin
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO ()
casadi__SDPSolver__loadPlugin
  :: String -> IO ()
casadi__SDPSolver__loadPlugin x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__SDPSolver__loadPlugin errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
sdpSolver_loadPlugin :: String -> IO ()
sdpSolver_loadPlugin = casadi__SDPSolver__loadPlugin


-- direct wrapper
foreign import ccall unsafe "casadi__SDPSolver__setSOCPOptions" c_casadi__SDPSolver__setSOCPOptions
  :: Ptr (Ptr StdString) -> Ptr SDPSolver' -> IO ()
casadi__SDPSolver__setSOCPOptions
  :: SDPSolver -> IO ()
casadi__SDPSolver__setSOCPOptions x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__SDPSolver__setSOCPOptions errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
sdpSolver_setSOCPOptions :: SDPSolverClass a => a -> IO ()
sdpSolver_setSOCPOptions x = casadi__SDPSolver__setSOCPOptions (castSDPSolver x)

