{-# OPTIONS_GHC -Wall #-}
{-# OPTIONS_GHC -fno-warn-unused-imports #-}
{-# OPTIONS_GHC -fno-warn-orphans #-}
{-# Language ForeignFunctionInterface #-}
{-# Language FlexibleInstances #-}
{-# Language MultiParamTypeClasses #-}

module Casadi.Core.Classes.StabilizedQPSolver
       (
         StabilizedQPSolver,
         StabilizedQPSolverClass(..),
         stabilizedQPSolver,
         stabilizedQPSolver_doc,
         stabilizedQPSolver_generateNativeCode,
         stabilizedQPSolver_loadPlugin,
         stabilizedQPSolver_setLPOptions,
       ) where


import Prelude hiding ( Functor )

import Data.Vector ( Vector )
import Foreign.C.Types
import Foreign.Marshal ( new, free )
import Foreign.Storable ( peek )
import Foreign.Ptr ( Ptr, nullPtr )
import Foreign.ForeignPtr ( newForeignPtr )
import System.IO.Unsafe ( unsafePerformIO ) -- for show instances

import Casadi.Core.Classes.PrintableObject
import Casadi.Internal.CToolsInstances ( )
import Casadi.Internal.FormatException ( formatException )
import Casadi.Internal.MarshalTypes ( StdVec, StdString) -- StdPair StdOstream'
import Casadi.Internal.Marshal ( Marshal(..), withMarshal )
import Casadi.Internal.WrapReturn ( WrapReturn(..) )
import Casadi.Core.Data
import Casadi.Core.Enums

instance Show StabilizedQPSolver where
  show = unsafePerformIO . printableObject_getDescription
-- direct wrapper
foreign import ccall unsafe "casadi__StabilizedQPSolver__CONSTRUCTOR" c_casadi__StabilizedQPSolver__CONSTRUCTOR
  :: Ptr (Ptr StdString) -> IO (Ptr StabilizedQPSolver')
casadi__StabilizedQPSolver__CONSTRUCTOR
  :: IO StabilizedQPSolver
casadi__StabilizedQPSolver__CONSTRUCTOR  =

  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__StabilizedQPSolver__CONSTRUCTOR errStrPtrP 
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
stabilizedQPSolver :: IO StabilizedQPSolver
stabilizedQPSolver = casadi__StabilizedQPSolver__CONSTRUCTOR


-- direct wrapper
foreign import ccall unsafe "casadi__StabilizedQPSolver__doc" c_casadi__StabilizedQPSolver__doc
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO (Ptr StdString)
casadi__StabilizedQPSolver__doc
  :: String -> IO String
casadi__StabilizedQPSolver__doc x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__StabilizedQPSolver__doc errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
stabilizedQPSolver_doc :: String -> IO String
stabilizedQPSolver_doc = casadi__StabilizedQPSolver__doc


-- direct wrapper
foreign import ccall unsafe "casadi__StabilizedQPSolver__generateNativeCode" c_casadi__StabilizedQPSolver__generateNativeCode
  :: Ptr (Ptr StdString) -> Ptr StabilizedQPSolver' -> Ptr StdString -> IO ()
casadi__StabilizedQPSolver__generateNativeCode
  :: StabilizedQPSolver -> String -> IO ()
casadi__StabilizedQPSolver__generateNativeCode x0 x1 =
  withMarshal x0 $ \x0' ->
  withMarshal x1 $ \x1' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__StabilizedQPSolver__generateNativeCode errStrPtrP x0' x1'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
stabilizedQPSolver_generateNativeCode :: StabilizedQPSolverClass a => a -> String -> IO ()
stabilizedQPSolver_generateNativeCode x = casadi__StabilizedQPSolver__generateNativeCode (castStabilizedQPSolver x)


-- direct wrapper
foreign import ccall unsafe "casadi__StabilizedQPSolver__loadPlugin" c_casadi__StabilizedQPSolver__loadPlugin
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO ()
casadi__StabilizedQPSolver__loadPlugin
  :: String -> IO ()
casadi__StabilizedQPSolver__loadPlugin x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__StabilizedQPSolver__loadPlugin errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
stabilizedQPSolver_loadPlugin :: String -> IO ()
stabilizedQPSolver_loadPlugin = casadi__StabilizedQPSolver__loadPlugin


-- direct wrapper
foreign import ccall unsafe "casadi__StabilizedQPSolver__setLPOptions" c_casadi__StabilizedQPSolver__setLPOptions
  :: Ptr (Ptr StdString) -> Ptr StabilizedQPSolver' -> IO ()
casadi__StabilizedQPSolver__setLPOptions
  :: StabilizedQPSolver -> IO ()
casadi__StabilizedQPSolver__setLPOptions x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__StabilizedQPSolver__setLPOptions errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
stabilizedQPSolver_setLPOptions :: StabilizedQPSolverClass a => a -> IO ()
stabilizedQPSolver_setLPOptions x = casadi__StabilizedQPSolver__setLPOptions (castStabilizedQPSolver x)

